<?php
/* ---------------------------------------------------------------------------
 * Loading Theme Scripts
 * --------------------------------------------------------------------------- */
add_action('wp_enqueue_scripts', 'dental_enqueue_scripts');
function dental_enqueue_scripts() {

	$library_uri = DENTAL_THEME_URI.'/framework';

	// comment reply script ------------------------------------------------------
	if (is_singular() AND comments_open()):
		 wp_enqueue_script( 'comment-reply' );
	endif;

	// scipts variable -----------------------------------------------------------
	$stickynav = ( dental_option("layout","layout-stickynav") ) ? "enable" : "disable";
	$loadingbar = ( dental_option("general","enable-loader") ) ? "enable" : "disable";
	$nicescroll = ( dental_option("general","enable-nicescroll") ) ? "enable" : "disable";
	if(is_rtl()) $rtl = true; else $rtl = false;

	$htype = dental_option('layout','header-type');
	$stickyele = "";
	switch( $htype ){
		case 'fullwidth-header':
		case 'boxed-header':
		case 'split-header fullwidth-header':
		case 'split-header boxed-header':
		case 'two-color-header':
			$stickyele = ".main-header-wrapper";
		break;

		case 'fullwidth-header header-align-center fullwidth-menu-header':
		case 'fullwidth-header header-align-left fullwidth-menu-header':
			$stickyele = ".menu-wrapper";
		break;

		case 'left-header':
		case 'left-header-boxed':
		case 'creative-header':
		case 'overlay-header':
			$stickyele = ".menu-wrapper";
			$stickynav = "disable";
		break;
	}

	wp_enqueue_script('ui.totop', $library_uri.'/js/jquery.ui.totop.min.js', array(), false, true);
	wp_enqueue_script('dental.jqplugins', $library_uri.'/js/jquery.plugins.js', array(), false, true);
	wp_enqueue_script('visualNav', $library_uri.'/js/jquery.visualNav.min.js', array(), false, true);

	if( is_page_template('tpl-sidenavigation.php') )
		wp_enqueue_script('stickyfloat', $library_uri.'/js/stickyfloat.js', array(), false, true);

	// reservation starts -------------------------------------------
	if( dental_is_plugin_active('designthemes-doctor-addon/designthemes-doctor-addon.php') ):
		wp_enqueue_script('jquery-ui-datepicker');
		wp_enqueue_style('jquery-ui-datepicker','http'.dental_ssl().'://code.jquery.com/ui/1.11.0/themes/smoothness/jquery-ui.css' );
		wp_enqueue_script('jq.reservation', $library_uri.'/js/reservation.js', array(), false, true);
		wp_localize_script('jq.reservation', 'dtAppointmentCustom', array(
			'plugin_url' => plugin_dir_url ( __FILE__ ),
			'eraptdatepicker' => esc_html__('Please Select Service and Date', 'dental'),
		));
	endif;
	// reservation ends ---------------------------------------------

	if( $loadingbar == 'enable' ) {
		wp_enqueue_script('pace', $library_uri.'/js/pace.min.js',array(),false,true);
		wp_localize_script('pace', 'paceOptions', array(
			'restartOnRequestAfter' => 'false',
			'restartOnPushState' => 'false'
		));
	}

	wp_enqueue_script('dental.jqcustom', $library_uri.'/js/custom.js', array(), false, true);

	wp_localize_script('dental.jqplugins', 'dttheme_urls', array(
		'theme_base_url' => esc_js(DENTAL_THEME_URI),
		'framework_base_url' => esc_js(DENTAL_THEME_URI).'/framework/',
		'ajaxurl' => admin_url('admin-ajax.php'),
		'url' => get_site_url(),
		'stickynav' => esc_js($stickynav),
		'stickyele' => esc_js($stickyele),
		'isRTL' => esc_js($rtl),
		'loadingbar' => esc_js($loadingbar),
		'nicescroll' => esc_js($nicescroll)
	));
	
	$picker = dental_option('general', 'enable-stylepicker');
	if( isset($picker) ) {
		wp_enqueue_script('cookie', $library_uri.'/js/jquery.cookie.min.js',array(),false,true);
		wp_enqueue_script('dental.jqcpanel', $library_uri.'/js/controlpanel.js',array(),false,true);
	}
}

/* ---------------------------------------------------------------------------
 * Meta tag for viewport scale
* --------------------------------------------------------------------------- */
function dental_viewport() {
	if(dental_option('general', 'enable-responsive')){
		echo "<meta name='viewport' content='width=device-width, initial-scale=1'>\r";
	}
}

/* ---------------------------------------------------------------------------
 * Scripts of Custom JS from Theme Back-End
* --------------------------------------------------------------------------- */
function dental_scripts_custom() {
	if( ($custom_js = dental_option('layout', 'customjs-content')) && dental_option('layout','enable-customjs') ){
		wp_add_inline_script('dental.jqcustom', dental_wp_kses(stripslashes($custom_js)) ,'after');
	}
}
add_action('wp_enqueue_scripts', 'dental_scripts_custom', 100);

/* ---------------------------------------------------------------------------
 * Loading Theme Styles
 * --------------------------------------------------------------------------- */
add_action( 'wp_enqueue_scripts', 'dental_enqueue_styles', 100 );
function dental_enqueue_styles() {

	$layout_opts = dental_option('layout');
	$general_opts = dental_option('general');
	$colors_opts = dental_option('colors');
	$pageopt_opts = dental_option('pageoptions');

	// site icons ---------------------------------------------------------------
	if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ):
		$url = ! empty ( $layout_opts ['favicon-url'] ) ? $layout_opts ['favicon-url'] : DENTAL_THEME_URI . "/images/favicon.ico";
		echo "<link href='$url' rel='shortcut icon' type='image/x-icon' />\n";
	
		$phone_url = ! empty ( $layout_opts ['apple-favicon'] ) ? $layout_opts ['apple-favicon'] : DENTAL_THEME_URI . "/images/apple-touch-icon.png";
		echo "<link href='$phone_url' rel='apple-touch-icon'/>\n";
	
		$phone_retina_url = ! empty ( $layout_opts ['apple-retina-favicon'] ) ? $layout_opts ['apple-retina-favicon'] : DENTAL_THEME_URI. "/images/apple-touch-icon-114x114.png";
		echo "<link href='$phone_retina_url' sizes='114x114' rel='apple-touch-icon'/>\n";
	
		$ipad_url = ! empty ( $layout_opts ['apple-ipad-favicon'] ) ? $layout_opts ['apple-ipad-favicon'] : DENTAL_THEME_URI . "/images/apple-touch-icon-72x72.png";
		echo "<link href='$ipad_url' sizes='72x72' rel='apple-touch-icon'/>\n";
	
		$ipad_retina_url = ! empty ( $layout_opts ['apple-ipad-retina-favicon'] ) ? $layout_opts ['apple-ipad-retina-favicon'] : DENTAL_THEME_URI . "/images/apple-touch-icon-144x144.png";
		echo "<link href='$ipad_retina_url' sizes='144x144' rel='apple-touch-icon'/>\n";
	endif;

	// wp_enqueue_style ---------------------------------------------------------------
	wp_enqueue_style( 'reset',			DENTAL_THEME_URI .'/css/reset.css', false, THEME_VERSION, 'all' );
	wp_enqueue_style( 'dental',			get_stylesheet_uri(), false, THEME_VERSION, 'all' );
	wp_enqueue_style( 'prettyphoto',	DENTAL_THEME_URI .'/css/prettyPhoto.css', false, THEME_VERSION, 'all' );

	if (function_exists('bp_add_cover_image_inline_css')) {
		$inline_css = bp_add_cover_image_inline_css( true );
		wp_add_inline_style( 'bp-parent-css', strip_tags( $inline_css['css_rules'] ) );
	}

	// icon fonts ---------------------------------------------------------------------
	wp_enqueue_style ( 'custom-font-awesome',		DENTAL_THEME_URI . '/css/font-awesome.min.css', array (), '4.3.0' );
	wp_enqueue_style ( 'pe-icon-7-stroke',			DENTAL_THEME_URI . '/css/pe-icon-7-stroke.css', array () );
	wp_enqueue_style ( 'stroke-gap-icons-style',	DENTAL_THEME_URI . '/css/stroke-gap-icons-style.css', array () );
	wp_enqueue_style ( 'icon-moon-ultimate',		DENTAL_THEME_URI . '/css/icon-moon-ultimate.css', array () );
	wp_enqueue_style ( 'icon-moon-solid',			DENTAL_THEME_URI . '/css/icon-moon.css', array () );
	wp_enqueue_style ( 'material-design-iconic',	DENTAL_THEME_URI . '/css/material-design-iconic-font.min.css', array () );

	// comingsoon css
	if(isset($pageopt_opts['enable-comingsoon']))
		wp_enqueue_style("dental.comingsoon",  	DENTAL_THEME_URI . "/css/comingsoon.css", false, THEME_VERSION, 'all' );

	// notfound css
	if ( is_404() )
		wp_enqueue_style("dental.notfound",	  	DENTAL_THEME_URI . "/css/notfound.css", false, THEME_VERSION, 'all' );

	// loader css
	if(isset($general_opts['enable-loader']))
		wp_enqueue_style("dental.loader",	  		DENTAL_THEME_URI . "/css/loaders.css", false, THEME_VERSION, 'all' );

	// show mobile slider
    if(empty($general_opts['show-mobileslider'])):
		$out =	'@media only screen and (max-width:320px), (max-width: 479px), (min-width: 480px) and (max-width: 767px), (min-width: 768px) and (max-width: 959px),
		 (max-width:1200px) { #slider { display:none !important; } }';
		wp_add_inline_style('dental', $out);		 
	endif;

	// woocommerce css
	if( function_exists( 'is_woocommerce' ) )
		wp_enqueue_style( 'dental.woo', 		DENTAL_THEME_URI .'/css/woocommerce.css', 'woocommerce-general-css', THEME_VERSION, 'all' );


	// static css
	if(isset($general_opts['enable-staticcss'])) :
		wp_enqueue_style("dental.static",  		DENTAL_THEME_URI . "/style-static.css", false, THEME_VERSION, 'all' );

	// skin css
	else :
		$skin	  = $colors_opts['theme-skin'];
		if($skin != 'custom')	wp_enqueue_style("skin", 	DENTAL_THEME_URI ."/css/skins/$skin/style.css");
	endif;

	// tribe-events -------------------------------------------------------------------
	wp_enqueue_style( 'dental.customevent', 		DENTAL_THEME_URI .'/tribe-events/custom.css', false, THEME_VERSION, 'all' );

	// responsive ---------------------------------------------------------------------
	if(dental_option('general', 'enable-responsive'))
		wp_enqueue_style("dental.responsive",  	DENTAL_THEME_URI . "/css/responsive.css", false, THEME_VERSION, 'all' );

	// google fonts -----------------------------------------------------------------
	$google_fonts = dental_fonts();
	$google_fonts = $google_fonts['all'];

	$subset 	  = dental_option('fonts','font-subset');
	if( $subset ) $subset = str_replace(' ', '', $subset);

	// style & weight  --------------------------------------------------------------
	if( $weight = dental_option('fonts', 'font-style') )
		$weight = ':'. implode( ',', $weight );

	$fonts = dental_fonts_selected();
	$fonts = array_unique($fonts);
	$fonts_url = ''; $font_families = array();
	foreach( $fonts as $font ){
		if( in_array( $font, $google_fonts ) ){
			// if google fonts
			$font_families[] .= $font . $weight;
		}
	}
	$query_args = array( 'family' => urlencode( implode( '|', $font_families ) ), 'subset' => urlencode( $subset ) );
	$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	wp_enqueue_style( 'dental-fonts', 		esc_url_raw($fonts_url), false, THEME_VERSION );
	wp_add_inline_style('dental-fonts', dental_styles_custom_font() );

	// custom css ---------------------------------------------------------------------
	wp_enqueue_style( 'dental.custom', 			DENTAL_THEME_URI .'/css/custom.css', false, THEME_VERSION, 'all' );

	// jquery scripts --------------------------------------------
	wp_enqueue_script('modernizr-custom', 	DENTAL_THEME_URI . '/framework/js/modernizr.custom.js', array('jquery'));

	// rtl ----------------------------------------------------------------------------
	if(is_rtl()) wp_enqueue_style('dental.rtl', 	DENTAL_THEME_URI . '/css/rtl.css', false, THEME_VERSION, 'all' );
}

/* ---------------------------------------------------------------------------
 * Styles Minify
 * --------------------------------------------------------------------------- */
function dental_styles_minify( $css ){

	// remove comments
	$css = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $css );	

	// remove whitespace
	$css = str_replace( array("\r\n", "\r", "\n", "\t", '  ', '    ', '    '), '', $css );

	return $css;
}

/* ---------------------------------------------------------------------------
 * Styles Dynamic
 * --------------------------------------------------------------------------- */
function dental_styles_dynamic() {

	ob_start();

	if( ! dental_opts_get( 'enable-staticcss' ) ){
		// custom colors.php
		$colors_opts = dental_option('colors');
		$skin	  = $colors_opts['theme-skin'];
		if($skin == 'custom'):
			include_once DENTAL_THEME_DIR . '/css/style-custom-color.php';
		endif;
		
		// default colors.php
		include_once DENTAL_THEME_DIR . '/css/style-default-color.php';

		// fonts.php
		include_once DENTAL_THEME_DIR . '/css/style-fonts.php';			
	}

	// custom optons css.php			
	if( ($custom_css = dental_option('layout','customcss-content')) &&  dental_option('layout','enable-customcss')):
		include_once DENTAL_THEME_DIR . '/css/dt-theme-option-custom-css.php';
	endif;

	$css = ob_get_contents();

	ob_get_clean();

	$css = dental_styles_minify( $css );

	wp_register_style( 'dental-combined', '', false, THEME_VERSION, 'all' );
	wp_enqueue_style( 'dental-combined' );
	wp_add_inline_style( 'dental-combined', $css );
}
add_action( 'wp_enqueue_scripts', 'dental_styles_dynamic', 100 );

/* ---------------------------------------------------------------------------
 * Styles of Custom Font
 * --------------------------------------------------------------------------- */
function dental_styles_custom_font() {	
	$fonts 		  = dental_fonts_selected();
	$font_custom  = dental_option('fonts','customfont-name');
	$font_custom2 = dental_option('fonts','customfont2-name');

	$out = '';

	if( $font_custom && in_array( $font_custom, $fonts ) ){
		$out .= '@font-face {';
			$out .= 'font-family: "'. $font_custom .'";';
			$out .= 'src: url("'. dental_option('fonts','customfont-eot') .'");';
			$out .= 'src: url("'. dental_option('fonts','customfont-eot') .'#iefix") format("embedded-opentype"),';
				$out .= 'url("'. dental_option('fonts','customfont-woff') .'") format("woff"),';
				$out .= 'url("'. dental_option('fonts','customfont-ttf') .'") format("truetype"),';
				$out .= 'url("'. dental_option('fonts','customfont-svg') . $font_custom .'") format("svg");';
			$out .= 'font-weight: normal;';
			$out .= 'font-style: normal;';
		$out .= '}';
	}
	
	if( $font_custom2 && in_array( $font_custom2, $fonts ) ){
		$out .= '@font-face {';
			$out .= 'font-family: "'. $font_custom2 .'";';
			$out .= 'src: url("'. dental_option('fonts','customfont2-eot') .'");';
			$out .= 'src: url("'. dental_option('fonts','customfont2-eot') .'#iefix") format("embedded-opentype"),';
				$out .= 'url("'. dental_option('fonts','customfont2-woff') .'") format("woff"),';
				$out .= 'url("'. dental_option('fonts','customfont2-ttf') .'") format("truetype"),';
				$out .= 'url("'. dental_option('fonts','customfont2-svg') . $font_custom2 .'") format("svg");';
			$out .= 'font-weight: normal;';
			$out .= 'font-style: normal;';
		$out .= '}';
	}

	return $out;
}

/* ---------------------------------------------------------------------------
 * Fonts Selected in Theme Options Panel
 * --------------------------------------------------------------------------- */
function dental_fonts_selected(){
	$fonts = array();
	
	$font_opts = dental_option('fonts');
	
	$fonts['content'] 		= !empty ( $font_opts['content-font'] ) 	? 	$font_opts['content-font'] 		: 'Oswald';
	$fonts['menu'] 			= !empty ( $font_opts['menu-font'] ) 		? 	$font_opts['menu-font'] 		: 'Oswald';
	$fonts['title'] 		= !empty ( $font_opts['pagetitle-font'] ) 	? 	$font_opts['pagetitle-font'] 	: 'Oswald';
	$fonts['h1'] 		= !empty ( $font_opts['h1-font'] ) 	? 	$font_opts['h1-font'] 		: 'Oswald';
	$fonts['h2'] 		= !empty ( $font_opts['h2-font'] ) 	? 	$font_opts['h2-font'] 		: 'Oswald';
	$fonts['h3'] 		= !empty ( $font_opts['h3-font'] ) 	? 	$font_opts['h3-font'] 		: 'Oswald';
	$fonts['h4'] 		= !empty ( $font_opts['h4-font'] ) 	? 	$font_opts['h4-font'] 		: 'Oswald';
	$fonts['h5'] 		= !empty ( $font_opts['h5-font'] ) 	? 	$font_opts['h5-font'] 		: 'Oswald';
	$fonts['h6'] 		= !empty ( $font_opts['h6-font'] ) 	? 	$font_opts['h6-font'] 		: 'Oswald';

	return $fonts;
}

/* ---------------------------------------------------------------------------
 * Site SSL Compatibility
 * --------------------------------------------------------------------------- */
function dental_ssl( $echo = false ){
	$ssl = '';
	if( is_ssl() ) $ssl = 's';
	if( $echo ){
		echo ($ssl);
	}
	return $ssl;
}

/* ---------------------------------------------------------------------------
 * Layout Selected in Theme Options Panel
 * --------------------------------------------------------------------------- */
add_action('wp_enqueue_scripts', 'dental_appearance_css', 102);
function dental_appearance_css() {
	$output = NULL;

	if (dental_option('layout', 'site-layout') == 'boxed') :

		if (dental_option('layout', 'bg-type') == 'bg-patterns') :
			$pattern 			= 	dental_option('layout', 'boxed-layout-pattern');
			$pattern_repeat 	= 	dental_option('layout', 'boxed-layout-pattern-repeat');
			$pattern_opacity 	= 	dental_option('layout', 'boxed-layout-pattern-opacity');
			$enable_color 		= 	dental_option('layout', 'show-boxed-layout-pattern-color');
			$pattern_color 		= 	dental_option('layout', 'boxed-layout-pattern-color');

			$output .= "body { ";

			if (!empty($pattern)) {
				$output .= "background-image:url('" . DENTAL_THEME_URI . "/framework/theme-options/images/patterns/{$pattern}');";
			}

			$output .= "background-repeat:$pattern_repeat;";
			if ($enable_color) {
				if (!empty($pattern_opacity)) {
					$color = dental_hex2rgb($pattern_color);
					$output .= "background-color:rgba($color[0],$color[1],$color[2],$pattern_opacity); ";
				} else {
					$output .= "background-color:$pattern_color;";
				}
			}
			$output .= "}\r\t";

		elseif (dental_option('layout', 'bg-type') == 'bg-custom') :
			$bg 			= 	dental_option('layout', 'boxed-layout-bg');
			$bg_repeat 		= 	dental_option('layout', 'boxed-layout-bg-repeat');
			$bg_opacity 	= 	dental_option('layout', 'boxed-layout-bg-opacity');
			$bg_color 		= 	dental_option('layout', 'boxed-layout-bg-color');
			$enable_color 	= 	dental_option('layout', 'show-boxed-layout-bg-color');
			$bg_position 	= 	dental_option('layout', 'boxed-layout-bg-position');

			$output .= "body { ";

			if (!empty($bg)) {
				$output .= "background-image:url($bg);";
				$output .= "background-repeat:$bg_repeat;";
				$output .= "background-position:$bg_position;";
			}

			if ($enable_color) {
				if (!empty($bg_opacity)) {
					$color = dental_hex2rgb($bg_color);
					$output .= "background-color:rgba($color[0],$color[1],$color[2],$bg_opacity);";
				} else {
					$output .= "background-color:$bg_color;";
				}
			}
			$output .= "}\r\t";
		endif;

	endif;
	
	if (!empty($output)) :
		wp_register_style( 'dental-layout', '' );
		wp_enqueue_style( 'dental-layout' );
		wp_add_inline_style('dental-layout', $output);
	endif;
}

/* ---------------------------------------------------------------------------
 * Body Class Filter for layout changes
 * --------------------------------------------------------------------------- */
function dental_body_classes( $classes ) {

	// layout
	$classes[] 		= 	'layout-'. dental_option('layout','site-layout');

	// header
	$header_type 	= 	dental_option('layout','header-type');
	if( isset($header_type) && ($header_type == 'left-header-boxed') ):
		$classes[]	=	'left-header left-header-boxed';
	elseif( isset($header_type) && ($header_type == 'creative-header') ):
		$classes[]	=	'left-header left-header-creative';
	else:
		$classes[]	=	$header_type;
	endif;

	$htrans 		= 	dental_option('layout', 'header-transparant');
	if(isset($htrans)):
		$classes[]	=	dental_option('layout', 'header-transparant');
	endif;
	
	$stickyhead		=	dental_option('layout','layout-stickynav');
	if(isset($stickyhead)):
		$classes[]	=	'sticky-header';
	endif;

	$standard		=	dental_option('layout','header-position');
	if( isset($standard) && ($standard == 'above slider') ):
		$classes[]	=	'standard-header';
	elseif( isset($standard) && ($standard == 'below slider') ):
		$classes[]	=	'standard-header header-below-slider';
	elseif ( isset($standard) && ($standard == 'on slider') ):
		$classes[]	=	'header-on-slider';
	endif;

	$topbar			=	dental_option('layout','layout-topbar');
	if(isset($topbar)):
		$classes[]	=	'header-with-topbar';
	endif;

	$wootype		=	dental_option('woo','product-style');
	$wootype		= 	!empty($wootype) ? 'woo-'.$wootype : 'woo-type1';
	$classes[]		=	$wootype;

	if( is_page() ) {
		$pageid = dental_ID();
		if(($slider_key = get_post_meta( $pageid, '_tpl_default_settings', true )) && (array_key_exists( 'show_slider', $slider_key )) ) {
			$classes[] = "page-with-slider";
		}
	} elseif( is_home() ) {
		$pageid = get_option('page_for_posts');
		if(($slider_key = get_post_meta( $pageid, '_tpl_default_settings', true )) && (array_key_exists( 'show_slider', $slider_key )) ) {
			$classes[] = "page-with-slider";
		}
	}

	return $classes;
}
add_filter( 'body_class', 'dental_body_classes' );?>