<?php


add_action( 'after_setup_theme', 'nancy_i18n' );
/**
 * Load the child theme textdomain for internationalization.
 *
 * Must be loaded before Genesis Framework /lib/init.php is included.
 * Translations can be filed in the /languages/ directory.
 *
 * @since 1.2.0
 */
function nancy_i18n() {
    load_child_theme_textdomain( 'nancy', get_stylesheet_directory() . '/languages' );
}

add_action( 'wp_enqueue_scripts', 'wsm_enqueue_assets' );
/**
 * Enqueue theme assets.
 */
function wsm_enqueue_assets() {
	wp_enqueue_style( 'nancy', get_stylesheet_uri() );
	wp_style_add_data( 'nancy', 'rtl', 'replace' );
}

// Start the engine
require_once( TEMPLATEPATH . '/lib/init.php' );

require_once( 'lib/init.php' );

// Calls the theme's constants & files
nancy_init();

// Editor Styles
add_editor_style( 'editor-style.css' );

// Create additional color style options

add_theme_support( 'genesis-style-selector',
	array(
		'nancy-burgundy' => __( 'Burgundy', 'nancy' ),
		'nancy-green' => __( 'Green', 'nancy' ),
		'nancy-brown' => __( 'Brown', 'nancy' ),
		'nancy-purple' => __( 'Purple', 'nancy' ),
		'nancy-pink' => __( 'Pink', 'nancy' ),
		'nancy-mixed' => __( 'Mixed', 'nancy' ),
	)
);


// Add Viewport meta tag for mobile browsers
add_action( 'genesis_meta', 'wsm_add_viewport_meta_tag' );
function wsm_add_viewport_meta_tag() {
    echo '<meta name="viewport" content="width=device-width, initial-scale=1.0"/>';
}

// Structural Wraps
add_theme_support( 'genesis-structural-wraps', array(
	'header',
	'nav',
	'subnav',
	'site-inner',
	'footer-widgets',
	'footer',
) );


/*
 * Add support for targeting individual browsers via CSS
 * See readme file located at /lib/js/css_browser_selector_readm.html
 * for a full explanation of available browser css selectors.
 */
add_action( 'get_header', 'wsm_load_scripts' );
function wsm_load_scripts() {
    wp_enqueue_script( 'browserselect', CHILD_URL . '/lib/js/css_browser_selector.js', array('jquery'), '0.4.0', TRUE );
}

// Force Stupid IE to NOT use compatibility mode
add_filter( 'wp_headers', 'wsm_keep_ie_modern' );
function wsm_keep_ie_modern( $headers ) {
        if ( isset( $_SERVER['HTTP_USER_AGENT'] ) && ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE' ) !== false ) ) {
                $headers['X-UA-Compatible'] = 'IE=edge,chrome=1';
        }
        return $headers;
}

// Add new image sizes
add_image_size( 'Blog Thumbnail', 140, 160, TRUE );

// Reposition the featured image
remove_action( 'genesis_entry_content', 'genesis_do_post_image', 8 );
add_action( 'genesis_entry_header', 'genesis_do_post_image', 5 ) ;

// Modify Post Info
add_filter( 'genesis_post_info', 'my_post_info_filter' );
function my_post_info_filter( $post_info ) {
if ( !is_page() ) {
	  $post_info = '[post_date format="m.j.y" before="' .  __( 'Posted on: ', 'nancy' ) . ' "] [post_author before="' .  __( 'By ', 'nancy' ) . ' "]'; //remove spaces after initial [
	  //$post_info = 'Custom text'; //edit this to whatever you'd like.
}
return $post_info;
}

// Customize the post meta function
add_filter( 'genesis_post_meta', 'post_meta_filter' );
function post_meta_filter( $post_meta ) {
	if ( is_single() ) {
    	$post_meta = '[post_categories sep=", " before="<span class=\'post-categories\'>' . __( 'Categories: ', 'nancy' ) . '" after="</span>"] [post_tags sep=", " before="<span class=\'post-tags\'>' . __( 'Tags: ', 'nancy' ) . '" after="</span>"]';
    	return $post_meta;
	}
}

// Add Read More button to blog page and archives
add_filter( 'excerpt_more', 'wsm_add_excerpt_more' );
add_filter( 'get_the_content_more_link', 'wsm_add_excerpt_more' );
add_filter( 'the_content_more_link', 'wsm_add_excerpt_more' );
function wsm_add_excerpt_more( $more ) {
    return ' <div class="more-link"><a href="' . get_permalink() . '" rel="nofollow">' . __( 'Read More', 'nancy' ) . '</a></div>';
}

// Customize the Author Box
add_filter( 'genesis_author_box', 'nancy_author_box' );
function nancy_author_box( $pattern ) {
	global $authordata;
	global $context;

	$authordata    = is_object( $authordata ) ? $authordata : get_userdata( get_query_var( 'author' ) );
	$gravatar_size = apply_filters( 'genesis_author_box_gravatar_size', 60, $context );
	$gravatar      = get_avatar( get_the_author_meta( 'email' ), $gravatar_size );
	$description   = wpautop( get_the_author_meta( 'description' ) );

	$pattern  = sprintf( '<section %s>', genesis_attr( 'author-box' ) );
	$pattern .= '<div>';
	$pattern .= $gravatar;
	$pattern .= sprintf( '<h4><span>%s</span></h4><strong class="authorbox-title">%s</strong>', __( 'About the Author', 'nancy' ), get_the_author_meta( 'display_name' ) );
	$pattern .= sprintf( '<p class="author-box-content" itemprop="description">%s</p></div>', $description );
	$pattern .= '</section>';

	return $pattern;
}

/** Modify the speak your mind text */
add_filter( 'genesis_comment_form_args', 'custom_comment_form_args' );
function custom_comment_form_args( $args ) {
    $args['title_reply'] = 'Leave a Comment';
    return $args;
}

//Add titles to Post and Category
add_action( 'genesis_before_loop', 'wsm_replace_arch_titles' );
function wsm_replace_arch_titles() {
	if ( is_category() ) {
		echo '<div class="page-title"><h3 class="entry-title">';
		$category = get_the_category('');
		echo $category[0]->cat_name;
		echo '</h3></div>';
	}

	elseif ( is_single() ) {
		echo '<div class="page-title"><h3 class="entry-title">' .  __( 'Blog', 'nancy' ) . '</h3></div>';
	}
}

/** Reposition Blog title */
add_action( 'genesis_before_loop', 'wsm_page_heading' );
function wsm_page_heading() {
	if ( is_page_template( 'page_blog.php' ) ) {
		echo '<div class="page-title">';
		echo '<div class="page-title"><h3 class="entry-title">' .  __( 'Blog', 'nancy' ) . '</h3></div>';
		remove_action( 'genesis_entry_header', 'wsm_replace_arch_titles' );
		echo '</div>';
	}

}

/** Remove Category Headline Title Description*/
remove_action( 'genesis_before_loop', 'genesis_do_taxonomy_title_description', 15 );

/*
 * Add support for Font Resizer
 */
 add_action('get_header', 'wsm_font_resizer');
function wsm_font_resizer() {
    wp_enqueue_script( 'font-resizer', CHILD_URL . '/lib/js/font-resizer.js', array( 'jquery' ), '1.0', TRUE );
}

// Changes Default Navigation to Primary & Footer

add_theme_support ( 'genesis-menus' ,
	array (
		'primary' => __( 'Primary Navigation Menu', 'nancy' ),
		'footer' => __( 'Footer Navigation Menu', 'nancy' ),
	)
);

// Remove Layouts
genesis_unregister_layout( 'content-sidebar-sidebar' );
genesis_unregister_layout( 'sidebar-sidebar-content' );
genesis_unregister_layout( 'sidebar-content-sidebar' );

// Setup Sidebars
unregister_sidebar( 'header-right' );
unregister_sidebar( 'sidebar-alt' );


genesis_register_sidebar( array(
	'id'			=> 'rotator',
	'name'			=> __( 'Rotator', 'nancy' ),
	'description'	=> __( 'This is the image rotator section.', 'nancy' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-main-content',
	'name'			=> __( 'Home Main Content', 'nancy' ),
	'description'	=> __( 'This is the Homepage Main Content section.', 'nancy' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-bottom-left',
	'name'			=> __( 'Home Bottom Left', 'nancy' ),
	'description'	=> __( 'This is the Home page bottom left section.', 'nancy' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-bottom-right',
	'name'			=> __( 'Home Bottom Right', 'nancy' ),
	'description'	=> __( 'This is the Home page bottom right section.', 'nancy' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'home-sidebar',
	'name'			=> __( 'Home Sidebar', 'nancy' ),
	'description'	=> __( 'This is the Homepage Sidebar.', 'nancy' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'blog-sidebar',
	'name'			=> __( 'Blog Sidebar', 'nancy' ),
	'description'	=> __( 'This is the Blog Page Sidebar.', 'nancy' ),
) );

genesis_register_sidebar( array(
	'id'			=> 'page-sidebar',
	'name'			=> __( 'Page Sidebar', 'nancy' ),
	'description'	=> __( 'This is the Page Sidebar.', 'nancy' ),
) );

// CSS Style for old IE
add_action( 'wp_head','wsm_rounded_corners' );
function wsm_rounded_corners() {
	echo '<style type="text/css">';
	echo '.nav-primary .wrap { behavior: url(' . CHILD_URL . '/lib/js/pie/PIE.htc); }';
	echo '</style>';
}

function my_plugin_body_class($classes) {
    $classes[] = 'header-image';
    return $classes;
}

add_filter('body_class', 'my_plugin_body_class');