<?php
/**
 * Adds the Call to Action widget.
 *
 */

add_action( 'widgets_init', create_function( '', "register_widget( 'WSM_Call_to_Action' );" ) );

class WSM_Call_to_Action extends WP_Widget {

	/**
	 * Constructor. Set the default widget options and create widget.
	 */
	function WSM_Call_to_Action() {
		$widget_ops = array( 'classname' => 'call-to-action', 'description' => __( 'Displays call to action links', 'nancy' ) );
		$this->WP_Widget( 'call-to-action', __( 'Web Savvy - Call to Action', 'nancy' ), $widget_ops );
	}

	/**
	 * Echo the widget content.
	 *
	 * @param array $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * @param array $instance The settings for the particular instance of the widget
	 */
	function widget( $args, $instance ) {
		extract( $args );

		$instance = wp_parse_args( (array)$instance, array(
			'title' => '',
			'cta1-text' => '',
			'cta1-url' => '',
			'cta1-icon' => '',
			'cta2-text' => '',
			'cta2-url' => '',
			'cta3-text' => '',
			'cta3-url' => '',
		) );

		echo $before_widget;
			
			// CTA 1
			
			if( !empty( $instance['cta1-text'] ) ) {  ?>
			
				<div class="cta1 cta">
				
				<div class="icon-box"><?php if(!empty($instance['cta1-icon'])) {?> <img class="icon" src="<?php echo strip_tags( $instance['cta1-icon'] ); ?>" alt="icon1"> <?php }?></div>
				
				<?php if( !empty( $instance['cta1-url'] ) ) : ?>
				
					<div class="text-box"><h3><a href="<?php echo esc_url( $instance['cta1-url'] ); ?>"><?php echo strip_tags( $instance['cta1-text'] ); ?></a></h3></div></div>
				
				<?php else : ?>
					<div class="text-box"><h3><a href="#"><?php echo strip_tags( $instance['cta1-text'] ); ?></a></h3></div></div>
				<?php endif;

			}
			
			// CTA 2
			
			if( !empty( $instance['cta2-text'] ) ) {  ?>
			
				<div class="cta2 cta">
				
				<div class="icon-box"><?php if(!empty($instance['cta2-icon'])) {?> <img class="icon" src="<?php echo strip_tags( $instance['cta2-icon'] ); ?>" alt="icon2"> <?php }?></div>
				
				<?php if(!empty($instance['cta2-url'])) : ?>
				
					<div class="text-box"><h3><a href="<?php echo esc_url( $instance['cta2-url'] ); ?>"><?php echo strip_tags( $instance['cta2-text'] ); ?></a></h3></div></div>
				
				<?php else : ?>
					<div class="text-box"><h3><a href="#"><?php echo strip_tags( $instance['cta2-text'] ); ?></a></h3></div></div>
				<?php endif;

			}
			
			// CTA 3
			
			if( !empty( $instance['cta3-text'] ) ) {  ?>
			
				<div class="cta3 cta">
				
				<div class="icon-box"><?php if(!empty($instance['cta3-icon'])) {?> <img class="icon" src="<?php echo strip_tags( $instance['cta3-icon'] ); ?>" alt="icon3"> <?php }?></div>
				
				<?php if(!empty($instance['cta3-url'])) : ?>
				
					<div class="text-box"><h3><a href="<?php echo esc_url( $instance['cta3-url'] ); ?>"><?php echo strip_tags( $instance['cta3-text'] ); ?></a></h3></div></div>
				
				<?php else : ?>
					<div class="text-box"><h3><a href="#"><?php echo strip_tags( $instance['cta3-text'] ); ?></a></h3></div></div>
				<?php endif;

			}
			
			// CTA 4
			
			if( !empty( $instance['cta4-text'] ) ) {  ?>
			
				<div class="cta4 cta">
				
				<div class="icon-box"><?php if(!empty($instance['cta4-icon'])) {?> <img class="icon" src="<?php echo strip_tags( $instance['cta4-icon'] ); ?>" alt="icon4"> <?php }?></div>
				
				<?php if(!empty($instance['cta4-url'])) : ?>
				
					<div class="text-box"><h3><a href="<?php echo esc_url( $instance['cta4-url'] ); ?>"><?php echo strip_tags( $instance['cta4-text'] ); ?></a></h3></div></div>
				
				<?php else : ?>
					<div class="text-box"><h3><a href="#"><?php echo strip_tags( $instance['cta4-text'] ); ?></a></h3></div></div>
				<?php endif;

			}
			

		echo $after_widget;
	}

	/** Update a particular instance.
	 *
	 * This function should check that $new_instance is set correctly.
	 * The newly calculated value of $instance should be returned.
	 * If "false" is returned, the instance won't be saved/updated.
	 *
	 * @param array $new_instance New settings for this instance as input by the user via form()
	 * @param array $old_instance Old settings for this instance
	 * @return array Settings to save or bool false to cancel saving
	 */
	function update( $new_instance, $old_instance ) {
		$new_instance['cta1-text'] = strip_tags( $new_instance['cta1-text'] );
		$new_instance['cta1-url'] = esc_url( $new_instance['cta1-url'] );
		$new_instance['cta1-icon'] = strip_tags( $new_instance['cta1-icon'] );
		$new_instance['cta2-text'] = strip_tags( $new_instance['cta2-text'] );
		$new_instance['cta2-url'] = esc_url( $new_instance['cta2-url'] );
		$new_instance['cta2-icon'] = strip_tags( $new_instance['cta2-icon'] );
		$new_instance['cta3-text'] = strip_tags( $new_instance['cta3-text'] );
		$new_instance['cta3-url'] = esc_url( $new_instance['cta3-url'] );
		$new_instance['cta3-icon'] = strip_tags( $new_instance['cta3-icon'] );
		$new_instance['cta4-text'] = strip_tags( $new_instance['cta4-text'] );
		$new_instance['cta4-url'] = esc_url( $new_instance['cta4-url'] );
		$new_instance['cta4-icon'] = strip_tags( $new_instance['cta4-icon'] );
		return $new_instance;
	}

	/** Echo the settings update form.
	 *
	 * @param array $instance Current settings
	 */
	function form( $instance ) {

		$instance = wp_parse_args( (array)$instance, array(
			'cta1-text' => '',
			'cta1-url' => '',
			'cta1-icon' => '',
			'cta2-text' => '',
			'cta2-url' => '',
			'cta2-icon' => '',
			'cta3-text' => '',
			'cta3-url' => '',
			'cta3-icon' => '',
			'cta4-text' => '',
			'cta4-url' => '',
			'cta4-icon' => '',
		) );

?>
		
		<p>
		<label for="<?php echo $this->get_field_id( 'cta1-text' ); ?>"><?php _e( '1st Call To Action Text', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id('cta1-text'); ?>" name="<?php echo $this->get_field_name( 'cta1-text' ); ?>" value="<?php echo esc_attr( $instance['cta1-text'] ); ?>" class="widefat" />
		</p>

		<p>
		<label for="<?php echo $this->get_field_id( 'cta1-url' ); ?>"><?php _e(' 1st Call To Action URL', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id('cta1-url'); ?>" name="<?php echo $this->get_field_name( 'cta1-url' ); ?>" value="<?php echo esc_url( $instance['cta1-url'] ); ?>" class="widefat" />
		</p>
		
		<p>
		<label for="<?php echo $this->get_field_id( 'cta1-icon' ); ?>"><?php _e( '1st Call To Action Icon', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta1-icon' ); ?>" name="<?php echo $this->get_field_name( 'cta1-icon' ); ?>" value="<?php echo esc_attr( $instance['cta1-icon'] ); ?>" class="widefat" />
		</p>
		
		<hr style="border: 0; border-bottom: 1px solid #DDD; padding: 0 0 10px;">

		<p>
		<label for="<?php echo $this->get_field_id( 'cta2-text' ); ?>"><?php _e( '2nd Call To Action Text', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta2-text' ); ?>" name="<?php echo $this->get_field_name( 'cta2-text' ); ?>" value="<?php echo esc_attr( $instance['cta2-text'] ); ?>" class="widefat" />
		</p>

		<p>
		<label for="<?php echo $this->get_field_id( 'cta2-url' ); ?>"><?php _e( '2nd Call To Action URL', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta2-url' ); ?>" name="<?php echo $this->get_field_name( 'cta2-url' ); ?>" value="<?php echo esc_url( $instance['cta2-url'] ); ?>" class="widefat" />
		</p>
		
		<p>
		<label for="<?php echo $this->get_field_id( 'cta2-icon' ); ?>"><?php _e( '2nd Call To Action Icon', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta2-icon' ); ?>" name="<?php echo $this->get_field_name( 'cta2-icon' ); ?>" value="<?php echo esc_attr( $instance['cta2-icon'] ); ?>" class="widefat" />
		</p>
		
		<hr style="border: 0; border-bottom: 1px solid #DDD; padding: 0 0 10px;">
		
		<p>
		<label for="<?php echo $this->get_field_id( 'cta3-text' ); ?>"><?php _e( '3rd Call To Action Text', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta3-text' ); ?>" name="<?php echo $this->get_field_name( 'cta3-text' ); ?>" value="<?php echo esc_attr( $instance['cta3-text'] ); ?>" class="widefat" />
		</p>

		<p>
		<label for="<?php echo $this->get_field_id( 'cta3-url' ); ?>"><?php _e( '3rd Call To Action URL', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta3-url' ); ?>" name="<?php echo $this->get_field_name( 'cta3-url' ); ?>" value="<?php echo esc_url( $instance['cta3-url'] ); ?>" class="widefat" />
		</p>	

		<p>
		<label for="<?php echo $this->get_field_id( 'cta3-icon' ); ?>"><?php _e( '3rd Call To Action Icon', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta3-icon' ); ?>" name="<?php echo $this->get_field_name( 'cta3-icon' ); ?>" value="<?php echo esc_attr( $instance['cta3-icon'] ); ?>" class="widefat" />
		</p>
		
		<hr style="border: 0; border-bottom: 1px solid #DDD; padding: 0 0 10px;">
		
		<p>
		<label for="<?php echo $this->get_field_id( 'cta4-text' ); ?>"><?php _e( '4th Call To Action Text', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta4-text' ); ?>" name="<?php echo $this->get_field_name( 'cta4-text' ); ?>" value="<?php echo esc_attr( $instance['cta4-text'] ); ?>" class="widefat" />
		</p>

		<p>
		<label for="<?php echo $this->get_field_id( 'cta4-url' ); ?>"><?php _e( '4th Call To Action URL', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta4-url' ); ?>" name="<?php echo $this->get_field_name( 'cta4-url' ); ?>" value="<?php echo esc_url( $instance['cta4-url'] ); ?>" class="widefat" />
		</p>	

		<p>
		<label for="<?php echo $this->get_field_id( 'cta4-icon' ); ?>"><?php _e( '4th Call To Action Icon', 'nancy' ); ?>:</label><br />
		<input type="text" id="<?php echo $this->get_field_id( 'cta4-icon' ); ?>" name="<?php echo $this->get_field_name( 'cta4-icon' ); ?>" value="<?php echo esc_attr( $instance['cta4-icon'] ); ?>" class="widefat" />
		</p>


	<?php
	}
}